Module parse_goodreader

Module parse_goodreader 

Functions

parse_goodreader_annotations
Parses the provided GoodReader annotations emitting a ParsedItem for each identified annotation and page number indicators if so desired. Use the ParseConfig to configure if page numbers should be included, etc.