parse_goodreader_annotations

Function parse_goodreader_annotations 

pub fn parse_goodreader_annotations(
    annotations: &str,
    config: &ParseConfig,
) -> Vec<ParsedItem>
Parses the provided GoodReader annotations emitting a ParsedItem for each identified annotation and page number indicators if so desired. Use the ParseConfig to configure if page numbers should be included, etc.