Functions
- parse_
goodreader_ annotations - Parses the provided GoodReader annotations emitting a
ParsedItemfor each identified annotation and page number indicators if so desired. Use theParseConfigto configure if page numbers should be included, etc.